==> connectagram_1.2.11.orig.tar.gz: connectagram-1.2.11/translations/connectagram_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Ланцюжок</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>Definitions</name>
    <message>
        <source>Definitions</source>
        <translation>Визначення</translation>
    </message>
    <message>
        <source>Downloading definition...</source>
        <translation>Завантаження визначень</translation>
    </message>
    <message>
        <source>Unsolved word</source>
        <translation>Нерозгадане слово</translation>
    </message>
</context>
<context>
    <name>Dictionary</name>
    <message>
        <source>Definition from Wiktionary, the free dictionary</source>
        <translation>Визначення з &quot;Wiktionary&quot;, безкоштовного словника</translation>
    </message>
    <message>
        <source>No definition found</source>
        <translation>Визначень не знайдено</translation>
    </message>
    <message>
        <source>Unable to connect to Wiktionary</source>
        <translation>Неможливо під&apos;єднатися до &quot;Wiktionary&quot;</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Тиночок</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Оберіть мову додатку:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примітка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Будь ласка, перезавантажте додаток, аби зміна мови набула чинності.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Нова гра</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Низька</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Середня</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Висока</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Дуже висока</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Мова:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Довжина слова:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Кількість слів:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n літера</numerusform>
            <numerusform>%n літер</numerusform>
            <numerusform>%n літери</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Кільця</translation>
    </message>
</context>
<context>
    <name>ScoreBoard</name>
    <message>
        <source>Scores</source>
        <translation>Бали</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Бали</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Час</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Слова</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Довжина</translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Сходинки</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Чорторий</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Хвиля</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Успіх</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Визначення</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Підказка</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Нова</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Обрати...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Деталі</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Підказка</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>В&amp;изначення</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>&amp;Scores</source>
        <translation>&amp;Бали</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вихід</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Мова &amp;додатку...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Щодо додатку</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Щодо &amp;Qt-версії</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Обрати гру</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Номер гри:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Вибачте</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Неможливо розпочати запитувану гру.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Щодо</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>&quot;Connectagram&quot;</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Гра, де розшифровують слова</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Авторські &amp;права; 2009-%1 створено Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Видано під ліцензією &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Визначення узято з &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Деталі</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Модель:</translation>
    </message>
    <message>
        <source>&amp;Resume</source>
        <translation>&amp;Продовжити</translation>
    </message>
</context>
</TS>

==> connectagram_1.3.1.orig.tar.gz: connectagram-1.3.1/translations/connectagram_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk_UA">
<context>
    <name>ChainPattern</name>
    <message>
        <source>Chain</source>
        <translation>Ланцюжок</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>Loading</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>FencePattern</name>
    <message>
        <source>Fence</source>
        <translation>Тиночок</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Оберіть мову додатку:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;System Language&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Примітка</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Будь ласка, перезавантажте додаток, аби зміна мови набула чинності.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Нова гра</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Низька</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Середня</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Висока</translation>
    </message>
    <message>
        <source>Very High</source>
        <translation>Дуже висока</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Мова:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Довжина слова:</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Кількість слів:</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n літера</numerusform>
            <numerusform>%n літер</numerusform>
            <numerusform>%n літери</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>RingsPattern</name>
    <message>
        <source>Rings</source>
        <translation>Кільця</translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Бали</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Час</translation>
    </message>
    <message>
        <source>Words</source>
        <translation>Слова</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>Довжина</translation>
    </message>
    <message>
        <source>#%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StairsPattern</name>
    <message>
        <source>Stairs</source>
        <translation>Сходинки</translation>
    </message>
</context>
<context>
    <name>TwistyPattern</name>
    <message>
        <source>Twisty</source>
        <translation>Чорторий</translation>
    </message>
</context>
<context>
    <name>WavePattern</name>
    <message>
        <source>Wave</source>
        <translation>Хвиля</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Success</source>
        <translation>Успіх</translation>
    </message>
    <message>
        <source>Loading</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Пауза</translation>
    </message>
    <message>
        <source>Definitions</source>
        <translation>Визначення</translation>
    </message>
    <message>
        <source>Hint</source>
        <translation>Підказка</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Гра</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Нова</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Обрати...</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Деталі</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Пауза</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Підказка</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>D&amp;efinitions</source>
        <translation>В&amp;изначення</translation>
    </message>
    <message>
        <source>D</source>
        <translation>D</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Вихід</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Налаштування</translation>
    </message>
    <message>
        <source>&amp;Dark Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>Мова &amp;додатку...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Допомога</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Щодо додатку</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Щодо &amp;Qt-версії</translation>
    </message>
    <message>
        <source>Choose Game</source>
        <translation>Обрати гру</translation>
    </message>
    <message>
        <source>Game Number:</source>
        <translation>Номер гри:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Вибачте</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Неможливо розпочати запитувану гру.</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Щодо</translation>
    </message>
    <message>
        <source>Connectagram</source>
        <translation>&quot;Connectagram&quot;</translation>
    </message>
    <message>
        <source>A word unscrambling game</source>
        <translation>Гра, де розшифровують слова</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 by Graeme Gott</source>
        <translation>Авторські &amp;права; 2009-%1 створено Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Видано під ліцензією &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Definitions are from &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</source>
        <translation>Визначення узято з &lt;a href=&quot;http://wiktionary.org/&quot;&gt;Wiktionary&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Деталі</translation>
    </message>
    <message>
        <source>Pattern:</source>
        <translation>Модель:</translation>
    </message>
</context>
</TS>
